==> easyflowutils-0.2.56-py3-none-any.whl: easyflowutils/schooler_client.py <==
from __future__ import annotations
from typing import Any, Optional
import requests


class SchoolerClient:
    BASE_URL = "https://api.schooler.biz"

    def __init__(self, client_id: str, client_secret: str, user_id: str, user_secret: str):
        self.client_id = client_id
        self.client_secret = client_secret
        self.user_id = user_id
        self.user_secret = user_secret
        self.access_token = None
        self.headers = {"Content-Type": "application/json"}

    def authenticate(self) -> SchoolerClient:
        url = f"{self.BASE_URL}/oauth/token"
        data = {
            "grant_type": "password",
            "client_id": self.client_id,
            "client_secret": self.client_secret,
            "user_id": self.user_id,
            "user_secret": self.user_secret
        }
        response = requests.post(url, json=data)
        response.raise_for_status()
        auth_data = response.json()
        self.access_token = auth_data["access_token"]
        self.headers["Authorization"] = f"Bearer {self.access_token}"
        return self

    def get(self, endpoint: str, params: Optional[dict[str, Any]] = None) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.get(url, headers=self.headers, params=params or {})
        response.raise_for_status()
        return response.json()

    def post(self, endpoint: str, data: dict[str, Any]) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.post(url, headers=self.headers, json=data)
        response.raise_for_status()
        return response.json()

    def put(self, endpoint: str, data: dict[str, Any]) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.put(url, headers=self.headers, json=data)
        response.raise_for_status()
        return response.json()

    # Courses
    def get_courses(self) -> dict[str, Any]:
        return self.get("courses")

    def get_course_details(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}")

    def get_course_lessons(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}/lessons")

    def get_course_students(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}/students")

    def enroll_students_in_course(self, course_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.post(f"courses/{course_id}/enroll_students", {"students_data": students_data})

    def update_students_in_course(self, course_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.put(f"courses/{course_id}/update_students", {"students_data": students_data})

    def delete_students_from_course(self, course_id: int, student_ids: list[int]) -> dict[str, Any]:
        return self.post(f"courses/{course_id}/delete_students", {"student_ids": student_ids})

    # Schools
    def get_schools(self) -> dict[str, Any]:
        return self.get("schools")

    def get_school_details(self, school_id: int) -> dict[str, Any]:
        return self.get(f"schools/{school_id}")

    def get_school_students(self, school_id: int) -> dict[str, Any]:
        return self.get(f"schools/{school_id}/students")

    def enroll_students_in_school(self, school_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.post(f"schools/{school_id}/enroll_students", {"students_data": students_data})

    def update_students_in_school(self, school_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.put(f"schools/{school_id}/update_students", {"students_data": students_data})

    # Students
    def search_students(self, email: Optional[str] = None, student_id: Optional[int] = None,
                        phone: Optional[str] = None) -> dict[str, Any]:
        params = {}
        if email:
            params["email"] = email
        if student_id:
            params["id"] = student_id
        if phone:
            params["phone"] = phone
        return self.get("students/search", params=params)

==> easyflowutils-0.2.59-py3-none-any.whl: easyflowutils/schooler_client.py <==
from __future__ import annotations
from typing import Any, Optional
import requests
from pydantic import BaseModel


class StudentData(BaseModel):
    name: str
    email: str
    password: str
    external_id: str


class SchoolerClient:
    BASE_URL = "https://api.schooler.biz"

    def __init__(self, client_id: str, client_secret: str, user_id: str, user_secret: str):
        self.client_id = client_id
        self.client_secret = client_secret
        self.user_id = user_id
        self.user_secret = user_secret
        self.access_token = None
        self.headers = {"Content-Type": "application/json"}

    def authenticate(self) -> SchoolerClient:
        url = f"{self.BASE_URL}/oauth/token"
        data = {
            "grant_type": "password",
            "client_id": self.client_id,
            "client_secret": self.client_secret,
            "user_id": self.user_id,
            "user_secret": self.user_secret
        }
        response = requests.post(url, json=data)
        response.raise_for_status()
        auth_data = response.json()
        self.access_token = auth_data["access_token"]
        self.headers["Authorization"] = f"Bearer {self.access_token}"
        return self

    def get(self, endpoint: str, params: Optional[dict[str, Any]] = None) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.get(url, headers=self.headers, params=params or {})
        response.raise_for_status()
        return response.json().get("data", {})

    def post(self, endpoint: str, data: dict[str, Any]) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.post(url, headers=self.headers, json=data)
        response.raise_for_status()
        return response.json()

    def put(self, endpoint: str, data: dict[str, Any]) -> dict[str, Any]:
        url = f"{self.BASE_URL}/api/v1/{endpoint}"
        response = requests.put(url, headers=self.headers, json=data)
        response.raise_for_status()
        return response.json()

    # Courses
    def get_courses(self) -> dict[str, Any]:
        return self.get("courses")

    def get_course_details(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}")

    def get_course_lessons(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}/lessons")

    def get_course_students(self, course_id: int) -> dict[str, Any]:
        return self.get(f"courses/{course_id}/students")

    def enroll_students_in_course(self, course_id: int, students_data: list[StudentsData]) -> dict[str, Any]:
        return self.post(f"courses/{course_id}/enroll_students", {"students_data": students_data})

    def update_students_in_course(self, course_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.put(f"courses/{course_id}/update_students", {"students_data": students_data})

    def delete_students_from_course(self, course_id: int, student_ids: list[int]) -> dict[str, Any]:
        return self.post(f"courses/{course_id}/delete_students", {"student_ids": student_ids})

    # Schools
    def get_schools(self) -> dict[str, Any]:
        return self.get("schools")

    def get_school_details(self, school_id: int) -> dict[str, Any]:
        return self.get(f"schools/{school_id}")

    def get_school_students(self, school_id: int) -> dict[str, Any]:
        return self.get(f"schools/{school_id}/students")

    def enroll_students_in_school(self, school_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.post(f"schools/{school_id}/enroll_students", {"students_data": students_data})

    def update_students_in_school(self, school_id: int, students_data: list[dict[str, Any]]) -> dict[str, Any]:
        return self.put(f"schools/{school_id}/update_students", {"students_data": students_data})

    # Students
    def search_students(self, email: Optional[str] = None, student_id: Optional[int] = None,
                        phone: Optional[str] = None) -> dict[str, Any]:
        params = {}
        if email:
            params["email"] = email
        if student_id:
            params["id"] = student_id
        if phone:
            params["phone"] = phone
        return self.get("students/search", params=params)
